"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Component(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CHANGE_DESCRIPTION_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    SUPPORTED_OS_VERSIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    version: builtins.str
    description: builtins.str
    change_description: builtins.str
    platform: builtins.str
    data: builtins.str
    kms_key_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    uri: builtins.str
    @property
    def supported_os_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        version: builtins.str = ...,
        description: builtins.str = ...,
        change_description: builtins.str = ...,
        platform: builtins.str = ...,
        data: builtins.str = ...,
        kms_key_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        uri: builtins.str = ...,
        supported_os_versions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["change_description", b"change_description", "data", b"data", "description", b"description", "kms_key_id", b"kms_key_id", "name", b"name", "platform", b"platform", "resource_info", b"resource_info", "supported_os_versions", b"supported_os_versions", "tags", b"tags", "uri", b"uri", "version", b"version"]) -> None: ...

global___Component = Component

@typing_extensions.final
class ImageBuilder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_FIELD_NUMBER: builtins.int
    DISTRIBUTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_PIPELINE_FIELD_NUMBER: builtins.int
    IMAGE_RECIPE_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_CONFIGURATION_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_CONFIGURATION_LOGGING_FIELD_NUMBER: builtins.int
    @property
    def component(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Component]: ...
    @property
    def distribution_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DistributionConfiguration]: ...
    @property
    def image(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Image]: ...
    @property
    def image_pipeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ImagePipeline]: ...
    @property
    def image_recipe(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ImageRecipe]: ...
    @property
    def infrastructure_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InfrastructureConfiguration]: ...
    @property
    def infrastructure_configuration_logging(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InfrastructureConfigurationLogging]: ...
    def __init__(
        self,
        *,
        component: collections.abc.Iterable[global___Component] | None = ...,
        distribution_configuration: collections.abc.Iterable[global___DistributionConfiguration] | None = ...,
        image: collections.abc.Iterable[global___Image] | None = ...,
        image_pipeline: collections.abc.Iterable[global___ImagePipeline] | None = ...,
        image_recipe: collections.abc.Iterable[global___ImageRecipe] | None = ...,
        infrastructure_configuration: collections.abc.Iterable[global___InfrastructureConfiguration] | None = ...,
        infrastructure_configuration_logging: collections.abc.Iterable[global___InfrastructureConfigurationLogging] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["component", b"component", "distribution_configuration", b"distribution_configuration", "image", b"image", "image_pipeline", b"image_pipeline", "image_recipe", b"image_recipe", "infrastructure_configuration", b"infrastructure_configuration", "infrastructure_configuration_logging", b"infrastructure_configuration_logging"]) -> None: ...

global___ImageBuilder = ImageBuilder

@typing_extensions.final
class DistributionConfigurationDistribution(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AmiDistributionConfigurationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    AMI_DISTRIBUTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    LICENSE_CONFIGURATION_ARNS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    region: builtins.str
    @property
    def ami_distribution_configuration(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def license_configuration_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        region: builtins.str = ...,
        ami_distribution_configuration: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        license_configuration_arns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ami_distribution_configuration", b"ami_distribution_configuration", "license_configuration_arns", b"license_configuration_arns", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___DistributionConfigurationDistribution = DistributionConfigurationDistribution

@typing_extensions.final
class DistributionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISTRIBUTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def distributions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DistributionConfigurationDistribution]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        distributions: collections.abc.Iterable[global___DistributionConfigurationDistribution] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "distributions", b"distributions", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DistributionConfiguration = DistributionConfiguration

@typing_extensions.final
class ImageImageTestsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IMAGE_TESTS_ENABLED_FIELD_NUMBER: builtins.int
    TIMEOUT_MINUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    image_tests_enabled: builtins.bool
    timeout_minutes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        image_tests_enabled: builtins.bool = ...,
        timeout_minutes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_tests_enabled", b"image_tests_enabled", "resource_info", b"resource_info", "timeout_minutes", b"timeout_minutes"]) -> None: ...

global___ImageImageTestsConfiguration = ImageImageTestsConfiguration

@typing_extensions.final
class Image(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IMAGE_TESTS_CONFIGURATION_FIELD_NUMBER: builtins.int
    IMAGE_RECIPE_ARN_FIELD_NUMBER: builtins.int
    DISTRIBUTION_CONFIGURATION_ARN_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_CONFIGURATION_ARN_FIELD_NUMBER: builtins.int
    ENHANCED_IMAGE_METADATA_ENABLED_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def image_tests_configuration(self) -> global___ImageImageTestsConfiguration: ...
    image_recipe_arn: builtins.str
    distribution_configuration_arn: builtins.str
    infrastructure_configuration_arn: builtins.str
    enhanced_image_metadata_enabled: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        image_tests_configuration: global___ImageImageTestsConfiguration | None = ...,
        image_recipe_arn: builtins.str = ...,
        distribution_configuration_arn: builtins.str = ...,
        infrastructure_configuration_arn: builtins.str = ...,
        enhanced_image_metadata_enabled: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_tests_configuration", b"image_tests_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["distribution_configuration_arn", b"distribution_configuration_arn", "enhanced_image_metadata_enabled", b"enhanced_image_metadata_enabled", "image_recipe_arn", b"image_recipe_arn", "image_tests_configuration", b"image_tests_configuration", "infrastructure_configuration_arn", b"infrastructure_configuration_arn", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Image = Image

@typing_extensions.final
class ImagePipelineImageTestsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IMAGE_TESTS_ENABLED_FIELD_NUMBER: builtins.int
    TIMEOUT_MINUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    image_tests_enabled: builtins.bool
    timeout_minutes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        image_tests_enabled: builtins.bool = ...,
        timeout_minutes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_tests_enabled", b"image_tests_enabled", "resource_info", b"resource_info", "timeout_minutes", b"timeout_minutes"]) -> None: ...

global___ImagePipelineImageTestsConfiguration = ImagePipelineImageTestsConfiguration

@typing_extensions.final
class ImagePipelineSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SCHEDULE_EXPRESSION_FIELD_NUMBER: builtins.int
    PIPELINE_EXECUTION_START_CONDITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    schedule_expression: builtins.str
    pipeline_execution_start_condition: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        schedule_expression: builtins.str = ...,
        pipeline_execution_start_condition: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_execution_start_condition", b"pipeline_execution_start_condition", "resource_info", b"resource_info", "schedule_expression", b"schedule_expression"]) -> None: ...

global___ImagePipelineSchedule = ImagePipelineSchedule

@typing_extensions.final
class ImagePipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IMAGE_TESTS_CONFIGURATION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    IMAGE_RECIPE_ARN_FIELD_NUMBER: builtins.int
    DISTRIBUTION_CONFIGURATION_ARN_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_CONFIGURATION_ARN_FIELD_NUMBER: builtins.int
    ENHANCED_IMAGE_METADATA_ENABLED_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def image_tests_configuration(self) -> global___ImagePipelineImageTestsConfiguration: ...
    status: builtins.str
    @property
    def schedule(self) -> global___ImagePipelineSchedule: ...
    image_recipe_arn: builtins.str
    distribution_configuration_arn: builtins.str
    infrastructure_configuration_arn: builtins.str
    enhanced_image_metadata_enabled: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        image_tests_configuration: global___ImagePipelineImageTestsConfiguration | None = ...,
        status: builtins.str = ...,
        schedule: global___ImagePipelineSchedule | None = ...,
        image_recipe_arn: builtins.str = ...,
        distribution_configuration_arn: builtins.str = ...,
        infrastructure_configuration_arn: builtins.str = ...,
        enhanced_image_metadata_enabled: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_tests_configuration", b"image_tests_configuration", "resource_info", b"resource_info", "schedule", b"schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "distribution_configuration_arn", b"distribution_configuration_arn", "enhanced_image_metadata_enabled", b"enhanced_image_metadata_enabled", "image_recipe_arn", b"image_recipe_arn", "image_tests_configuration", b"image_tests_configuration", "infrastructure_configuration_arn", b"infrastructure_configuration_arn", "name", b"name", "resource_info", b"resource_info", "schedule", b"schedule", "status", b"status", "tags", b"tags"]) -> None: ...

global___ImagePipeline = ImagePipeline

@typing_extensions.final
class ImageRecipeComponentConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPONENT_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    component_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        component_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_arn", b"component_arn", "resource_info", b"resource_info"]) -> None: ...

global___ImageRecipeComponentConfiguration = ImageRecipeComponentConfiguration

@typing_extensions.final
class ImageRecipeEbsInstanceBlockDeviceSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    DELETE_ON_TERMINATION_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    encrypted: builtins.bool
    delete_on_termination: builtins.bool
    iops: builtins.int
    kms_key_id: builtins.str
    snapshot_id: builtins.str
    volume_size: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        encrypted: builtins.bool = ...,
        delete_on_termination: builtins.bool = ...,
        iops: builtins.int = ...,
        kms_key_id: builtins.str = ...,
        snapshot_id: builtins.str = ...,
        volume_size: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_on_termination", b"delete_on_termination", "encrypted", b"encrypted", "iops", b"iops", "kms_key_id", b"kms_key_id", "resource_info", b"resource_info", "snapshot_id", b"snapshot_id", "volume_size", b"volume_size", "volume_type", b"volume_type"]) -> None: ...

global___ImageRecipeEbsInstanceBlockDeviceSpecification = ImageRecipeEbsInstanceBlockDeviceSpecification

@typing_extensions.final
class ImageRecipeInstanceBlockDeviceMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    VIRTUAL_NAME_FIELD_NUMBER: builtins.int
    NO_DEVICE_FIELD_NUMBER: builtins.int
    EBS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    device_name: builtins.str
    virtual_name: builtins.str
    no_device: builtins.str
    @property
    def ebs(self) -> global___ImageRecipeEbsInstanceBlockDeviceSpecification: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device_name: builtins.str = ...,
        virtual_name: builtins.str = ...,
        no_device: builtins.str = ...,
        ebs: global___ImageRecipeEbsInstanceBlockDeviceSpecification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs", b"ebs", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_name", b"device_name", "ebs", b"ebs", "no_device", b"no_device", "resource_info", b"resource_info", "virtual_name", b"virtual_name"]) -> None: ...

global___ImageRecipeInstanceBlockDeviceMapping = ImageRecipeInstanceBlockDeviceMapping

@typing_extensions.final
class ImageRecipe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    COMPONENTS_FIELD_NUMBER: builtins.int
    BLOCK_DEVICE_MAPPINGS_FIELD_NUMBER: builtins.int
    PARENT_IMAGE_FIELD_NUMBER: builtins.int
    WORKING_DIRECTORY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    version: builtins.str
    @property
    def components(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ImageRecipeComponentConfiguration]: ...
    @property
    def block_device_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ImageRecipeInstanceBlockDeviceMapping]: ...
    parent_image: builtins.str
    working_directory: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        version: builtins.str = ...,
        components: collections.abc.Iterable[global___ImageRecipeComponentConfiguration] | None = ...,
        block_device_mappings: collections.abc.Iterable[global___ImageRecipeInstanceBlockDeviceMapping] | None = ...,
        parent_image: builtins.str = ...,
        working_directory: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_device_mappings", b"block_device_mappings", "components", b"components", "description", b"description", "name", b"name", "parent_image", b"parent_image", "resource_info", b"resource_info", "tags", b"tags", "version", b"version", "working_directory", b"working_directory"]) -> None: ...

global___ImageRecipe = ImageRecipe

@typing_extensions.final
class InfrastructureConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LoggingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ResourceTagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    INSTANCE_TYPES_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    KEY_PAIR_FIELD_NUMBER: builtins.int
    TERMINATE_INSTANCE_ON_FAILURE_FIELD_NUMBER: builtins.int
    INSTANCE_PROFILE_NAME_FIELD_NUMBER: builtins.int
    SNS_TOPIC_ARN_FIELD_NUMBER: builtins.int
    RESOURCE_TAGS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def instance_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def logging(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    subnet_id: builtins.str
    key_pair: builtins.str
    terminate_instance_on_failure: builtins.bool
    instance_profile_name: builtins.str
    sns_topic_arn: builtins.str
    @property
    def resource_tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        instance_types: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        logging: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        subnet_id: builtins.str = ...,
        key_pair: builtins.str = ...,
        terminate_instance_on_failure: builtins.bool = ...,
        instance_profile_name: builtins.str = ...,
        sns_topic_arn: builtins.str = ...,
        resource_tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "instance_profile_name", b"instance_profile_name", "instance_types", b"instance_types", "key_pair", b"key_pair", "logging", b"logging", "name", b"name", "resource_info", b"resource_info", "resource_tags", b"resource_tags", "security_group_ids", b"security_group_ids", "sns_topic_arn", b"sns_topic_arn", "subnet_id", b"subnet_id", "tags", b"tags", "terminate_instance_on_failure", b"terminate_instance_on_failure"]) -> None: ...

global___InfrastructureConfiguration = InfrastructureConfiguration

@typing_extensions.final
class InfrastructureConfigurationS3Logs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_NAME_FIELD_NUMBER: builtins.int
    S3_KEY_PREFIX_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket_name: builtins.str
    s3_key_prefix: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket_name: builtins.str = ...,
        s3_key_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_bucket_name", b"s3_bucket_name", "s3_key_prefix", b"s3_key_prefix"]) -> None: ...

global___InfrastructureConfigurationS3Logs = InfrastructureConfigurationS3Logs

@typing_extensions.final
class InfrastructureConfigurationLogging(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_LOGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3_logs(self) -> global___InfrastructureConfigurationS3Logs: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_logs: global___InfrastructureConfigurationS3Logs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_logs", b"s3_logs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_logs", b"s3_logs"]) -> None: ...

global___InfrastructureConfigurationLogging = InfrastructureConfigurationLogging



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.authentication.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SelfSubjectReview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def status(self) -> global___SelfSubjectReviewStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        status: global___SelfSubjectReviewStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___SelfSubjectReview = SelfSubjectReview

@typing_extensions.final
class SelfSubjectReviewStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def user_info(self) -> kubernetes.kubernetes_io.k8s.api.authentication.v1_pb2.UserInfo: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        user_info: kubernetes.kubernetes_io.k8s.api.authentication.v1_pb2.UserInfo | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "user_info", b"user_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "user_info", b"user_info"]) -> None: ...

global___SelfSubjectReviewStatus = SelfSubjectReviewStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_apimanagement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)azure/azure_microsoft_apimanagement.proto\x12)oak9.tython.azure.microsoft_apimanagement\x1a\x13shared/shared.proto\"\x8e\x15\n\x17Microsoft_ApiManagement\x12\x43\n\x07service\x18\x01 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_apimanagement.Service\x12N\n\rservice_users\x18\x02 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_apimanagement.ServiceUsers\x12\x62\n\x18service_api_version_sets\x18\x03 \x03(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.ServiceApiVersionSets\x12L\n\x0cservice_apis\x18\x04 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_apimanagement.ServiceApis\x12\x63\n\x18service_apis_diagnostics\x18\x05 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_apimanagement.ServiceApisDiagnostics\x12\x61\n\x17service_apis_operations\x18\x06 \x03(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.ServiceApisOperations\x12r\n service_apis_operations_policies\x18\x07 \x03(\x0b\x32H.oak9.tython.azure.microsoft_apimanagement.ServiceApisOperationsPolicies\x12j\n\x1cservice_apis_operations_tags\x18\x08 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_apimanagement.ServiceApisOperationsTags\x12]\n\x15service_apis_policies\x18\t \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.ServiceApisPolicies\x12l\n\x1dservice_apis_tag_descriptions\x18\n \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_apimanagement.ServiceApisTagDescriptions\x12U\n\x11service_apis_tags\x18\x0b \x03(\x0b\x32:.oak9.tython.azure.microsoft_apimanagement.ServiceApisTags\x12m\n\x1dservice_authorization_servers\x18\x0c \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_apimanagement.ServiceAuthorizationServers\x12T\n\x10service_backends\x18\r \x03(\x0b\x32:.oak9.tython.azure.microsoft_apimanagement.ServiceBackends\x12\\\n\x14service_certificates\x18\x0e \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.ServiceCertificates\x12Z\n\x13service_diagnostics\x18\x0f \x03(\x0b\x32=.oak9.tython.azure.microsoft_apimanagement.ServiceDiagnostics\x12T\n\x10service_gateways\x18\x10 \x03(\x0b\x32:.oak9.tython.azure.microsoft_apimanagement.ServiceGateways\x12]\n\x15service_gateways_apis\x18\x11 \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.ServiceGatewaysApis\x12\x82\x01\n(service_gateways_hostname_configurations\x18\x12 \x03(\x0b\x32P.oak9.tython.azure.microsoft_apimanagement.ServiceGatewaysHostnameConfigurations\x12P\n\x0eservice_groups\x18\x13 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_apimanagement.ServiceGroups\x12[\n\x14service_groups_users\x18\x14 \x03(\x0b\x32=.oak9.tython.azure.microsoft_apimanagement.ServiceGroupsUsers\x12g\n\x1aservice_identity_providers\x18\x15 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_apimanagement.ServiceIdentityProviders\x12R\n\x0fservice_loggers\x18\x16 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_apimanagement.ServiceLoggers\x12[\n\x14service_named_values\x18\x17 \x03(\x0b\x32=.oak9.tython.azure.microsoft_apimanagement.ServiceNamedValues\x12^\n\x15service_notifications\x18\x18 \x03(\x0b\x32?.oak9.tython.azure.microsoft_apimanagement.ServiceNotifications\x12r\n service_openid_connect_providers\x18\x19 \x03(\x0b\x32H.oak9.tython.azure.microsoft_apimanagement.ServiceOpenidConnectProviders\x12T\n\x10service_policies\x18\x1a \x03(\x0b\x32:.oak9.tython.azure.microsoft_apimanagement.ServicePolicies\x12T\n\x10service_products\x18\x1b \x03(\x0b\x32:.oak9.tython.azure.microsoft_apimanagement.ServiceProducts\x12^\n\x15service_subscriptions\x18\x1c \x03(\x0b\x32?.oak9.tython.azure.microsoft_apimanagement.ServiceSubscriptions\"\xb7\x02\n\x0cServiceUsers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_type\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirmation\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x12\n\nfirst_name\x18\x06 \x01(\t\x12S\n\nidentities\x18\x07 \x03(\x0b\x32?.oak9.tython.azure.microsoft_apimanagement.UserIdentityContract\x12\x11\n\tlast_name\x18\x08 \x01(\t\x12\x0c\n\x04note\x18\t \x01(\t\x12\x10\n\x08password\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\"4\n\x14UserIdentityContract\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\"\xa9\x01\n\rServiceTenant\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x13\n\x0bprimary_key\x18\x04 \x01(\t\x12\x14\n\x0cprincipal_id\x18\x05 \x01(\t\x12\x15\n\rsecondary_key\x18\x06 \x01(\t\"\x86\x02\n\x10ServiceTemplates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12h\n\nparameters\x18\x05 \x03(\x0b\x32T.oak9.tython.azure.microsoft_apimanagement.EmailTemplateParametersContractProperties\x12\x0f\n\x07subject\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\"]\n)EmailTemplateParametersContractProperties\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"j\n\x0bServiceTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\"\xe6\x01\n\x14ServiceSubscriptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rallow_tracing\x18\x03 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x10\n\x08owner_id\x18\x05 \x01(\t\x12\x13\n\x0bprimary_key\x18\x06 \x01(\t\x12\r\n\x05scope\x18\x07 \x01(\t\x12\x15\n\rsecondary_key\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\"\x90\x03\n\x0eServiceSchemas\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12Y\n\x08\x64ocument\x18\x04 \x03(\x0b\x32G.oak9.tython.azure.microsoft_apimanagement.ServiceSchemas.DocumentEntry\x12\x13\n\x0bschema_type\x18\x05 \x01(\t\x12S\n\x05value\x18\x06 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_apimanagement.ServiceSchemas.ValueEntry\x1a/\n\rDocumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x13ServiceProductsTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x17ServiceProductsPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"^\n\x15ServiceProductsGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\\\n\x13ServiceProductsApis\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x80\x05\n\x0fServiceProducts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x61pproval_required\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x1d\n\x15subscription_required\x18\x07 \x01(\x08\x12\x1b\n\x13subscriptions_limit\x18\x08 \x01(\x05\x12\r\n\x05terms\x18\t \x01(\t\x12]\n\x15service_products_tags\x18\n \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.ServiceProductsTags\x12]\n\x15service_products_apis\x18\x0b \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.ServiceProductsApis\x12\x61\n\x17service_products_groups\x18\x0c \x03(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.ServiceProductsGroups\x12\x65\n\x19service_products_policies\x18\r \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_apimanagement.ServiceProductsPolicies\"\xf3\x01\n!ServicePrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12{\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32L.oak9.tython.azure.microsoft_apimanagement.PrivateLinkServiceConnectionState\"P\n\x15ServicePortalsettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x01\n\x16ServicePortalRevisions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nis_current\x18\x04 \x01(\x08\"w\n\x0fServicePolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"\xd6\x01\n\x1dServiceOpenidConnectProviders\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x15\n\rclient_secret\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\x12\x19\n\x11metadata_endpoint\x18\x07 \x01(\t\"k\n\"ServiceNotificationsRecipientUsers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n#ServiceNotificationsRecipientEmails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xdb\x02\n\x14ServiceNotifications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12|\n%service_notifications_recipient_users\x18\x03 \x03(\x0b\x32M.oak9.tython.azure.microsoft_apimanagement.ServiceNotificationsRecipientUsers\x12~\n&service_notifications_recipient_emails\x18\x04 \x03(\x0b\x32N.oak9.tython.azure.microsoft_apimanagement.ServiceNotificationsRecipientEmails\"\xfe\x01\n\x12ServiceNamedValues\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12^\n\tkey_vault\x18\x04 \x01(\x0b\x32K.oak9.tython.azure.microsoft_apimanagement.KeyVaultContractCreateProperties\x12\x0e\n\x06secret\x18\x05 \x01(\x08\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\r\n\x05value\x18\x07 \x01(\t\"\xc0\x02\n\x0eServiceLoggers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12_\n\x0b\x63redentials\x18\x03 \x03(\x0b\x32J.oak9.tython.azure.microsoft_apimanagement.ServiceLoggers.CredentialsEntry\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0bis_buffered\x18\x05 \x01(\x08\x12\x13\n\x0blogger_type\x18\x06 \x01(\t\x12\x13\n\x0bresource_id\x18\x07 \x01(\t\x1a\x32\n\x10\x43redentialsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdd\x02\n\x18ServiceIdentityProviders\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x61llowed_tenants\x18\x03 \x03(\t\x12\x11\n\tauthority\x18\x04 \x01(\t\x12\x11\n\tclient_id\x18\x05 \x01(\t\x12\x15\n\rclient_secret\x18\x06 \x01(\t\x12\"\n\x1apassword_reset_policy_name\x18\x07 \x01(\t\x12#\n\x1bprofile_editing_policy_name\x18\x08 \x01(\t\x12\x1a\n\x12signin_policy_name\x18\t \x01(\t\x12\x15\n\rsignin_tenant\x18\n \x01(\t\x12\x1a\n\x12signup_policy_name\x18\x0b \x01(\t\x12\x0c\n\x04type\x18\x0c \x01(\t\"[\n\x12ServiceGroupsUsers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xa4\x01\n\rServiceGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\"\x83\x02\n%ServiceGatewaysHostnameConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x03 \x01(\t\x12\x10\n\x08hostname\x18\x04 \x01(\t\x12\x15\n\rhttp2_enabled\x18\x05 \x01(\x08\x12$\n\x1cnegotiate_client_certificate\x18\x06 \x01(\x08\x12\x15\n\rtls10_enabled\x18\x07 \x01(\x08\x12\x15\n\rtls11_enabled\x18\x08 \x01(\x08\"\x82\x01\n%ServiceGatewaysCertificateAuthorities\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_trusted\x18\x03 \x01(\x08\"x\n\x13ServiceGatewaysApis\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x03 \x01(\t\"\xd2\x02\n\x0fServiceGateways\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12^\n\rlocation_data\x18\x04 \x01(\x0b\x32G.oak9.tython.azure.microsoft_apimanagement.ResourceLocationDataContract\x12\x82\x01\n(service_gateways_certificate_authorities\x18\x05 \x03(\x0b\x32P.oak9.tython.azure.microsoft_apimanagement.ServiceGatewaysCertificateAuthorities\"g\n\x1cResourceLocationDataContract\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x19\n\x11\x63ountry_or_region\x18\x02 \x01(\t\x12\x10\n\x08\x64istrict\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xee\x03\n\x12ServiceDiagnostics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nalways_log\x18\x03 \x01(\t\x12V\n\x07\x62\x61\x63kend\x18\x04 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_apimanagement.PipelineDiagnosticSettings\x12W\n\x08\x66rontend\x18\x05 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_apimanagement.PipelineDiagnosticSettings\x12!\n\x19http_correlation_protocol\x18\x06 \x01(\t\x12\x15\n\rlog_client_ip\x18\x07 \x01(\x08\x12\x11\n\tlogger_id\x18\x08 \x01(\t\x12\x1d\n\x15operation_name_format\x18\t \x01(\t\x12M\n\x08sampling\x18\n \x01(\x0b\x32;.oak9.tython.azure.microsoft_apimanagement.SamplingSettings\x12\x11\n\tverbosity\x18\x0b \x01(\t\"h\n\x1fServiceContentTypesContentItems\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd5\x01\n\x13ServiceContentTypes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12w\n#service_content_types_content_items\x18\x03 \x03(\x0b\x32J.oak9.tython.azure.microsoft_apimanagement.ServiceContentTypesContentItems\"\xdc\x01\n\x13ServiceCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\x12^\n\tkey_vault\x18\x04 \x01(\x0b\x32K.oak9.tython.azure.microsoft_apimanagement.KeyVaultContractCreateProperties\x12\x10\n\x08password\x18\x05 \x01(\t\"Y\n KeyVaultContractCreateProperties\x12\x1a\n\x12identity_client_id\x18\x01 \x01(\t\x12\x19\n\x11secret_identifier\x18\x02 \x01(\t\"\xb6\x01\n\rServiceCaches\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x63onnection_string\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0bresource_id\x18\x05 \x01(\t\x12\x19\n\x11use_from_location\x18\x06 \x01(\t\"\x9c\x04\n\x0fServiceBackends\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Z\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_apimanagement.BackendCredentialsContract\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12p\n\x16service_fabric_cluster\x18\x05 \x01(\x0b\x32P.oak9.tython.azure.microsoft_apimanagement.BackendServiceFabricClusterProperties\x12\x10\n\x08protocol\x18\x06 \x01(\t\x12N\n\x05proxy\x18\x07 \x01(\x0b\x32?.oak9.tython.azure.microsoft_apimanagement.BackendProxyContract\x12\x13\n\x0bresource_id\x18\x08 \x01(\t\x12\r\n\x05title\x18\t \x01(\t\x12L\n\x03tls\x18\n \x01(\x0b\x32?.oak9.tython.azure.microsoft_apimanagement.BackendTlsProperties\x12\x0b\n\x03url\x18\x0b \x01(\t\"]\n\x14\x42\x61\x63kendTlsProperties\x12\"\n\x1avalidate_certificate_chain\x18\x01 \x01(\x08\x12!\n\x19validate_certificate_name\x18\x02 \x01(\x08\"G\n\x14\x42\x61\x63kendProxyContract\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\"\xb7\x02\n%BackendServiceFabricClusterProperties\x12\x1d\n\x15\x63lient_certificate_id\x18\x01 \x01(\t\x12$\n\x1c\x63lient_certificatethumbprint\x18\x02 \x01(\t\x12\x1c\n\x14management_endpoints\x18\x03 \x03(\t\x12(\n max_partition_resolution_retries\x18\x04 \x01(\x05\x12&\n\x1eserver_certificate_thumbprints\x18\x05 \x03(\t\x12Y\n\x11server_x509_names\x18\x06 \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.X509CertificateName\"J\n\x13X509CertificateName\x12%\n\x1dissuer_certificate_thumbprint\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd4\x03\n\x1a\x42\x61\x63kendCredentialsContract\x12g\n\rauthorization\x18\x01 \x01(\x0b\x32P.oak9.tython.azure.microsoft_apimanagement.BackendAuthorizationHeaderCredentials\x12\x13\n\x0b\x63\x65rtificate\x18\x02 \x03(\t\x12\x17\n\x0f\x63\x65rtificate_ids\x18\x03 \x03(\t\x12\x61\n\x06header\x18\x04 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_apimanagement.BackendCredentialsContract.HeaderEntry\x12_\n\x05query\x18\x05 \x03(\x0b\x32P.oak9.tython.azure.microsoft_apimanagement.BackendCredentialsContract.QueryEntry\x1a-\n\x0bHeaderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n%BackendAuthorizationHeaderCredentials\x12\x11\n\tparameter\x18\x01 \x01(\t\x12\x0e\n\x06scheme\x18\x02 \x01(\t\"\xed\x04\n\x1bServiceAuthorizationServers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16\x61uthorization_endpoint\x18\x03 \x01(\t\x12\x1d\n\x15\x61uthorization_methods\x18\x04 \x03(\t\x12$\n\x1c\x62\x65\x61rer_token_sending_methods\x18\x05 \x03(\t\x12$\n\x1c\x63lient_authentication_method\x18\x06 \x03(\t\x12\x11\n\tclient_id\x18\x07 \x01(\t\x12$\n\x1c\x63lient_registration_endpoint\x18\x08 \x01(\t\x12\x15\n\rclient_secret\x18\t \x01(\t\x12\x15\n\rdefault_scope\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x0c \x01(\t\x12\x13\n\x0bgrant_types\x18\r \x03(\t\x12\x1f\n\x17resource_owner_password\x18\x0e \x01(\t\x12\x1f\n\x17resource_owner_username\x18\x0f \x01(\t\x12\x15\n\rsupport_state\x18\x10 \x01(\x08\x12\x64\n\x15token_body_parameters\x18\x11 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_apimanagement.TokenBodyParameterContract\x12\x16\n\x0etoken_endpoint\x18\x12 \x01(\t\"9\n\x1aTokenBodyParameterContract\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xdd\x01\n\x15ServiceApiVersionSets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x1b\n\x13version_header_name\x18\x05 \x01(\t\x12\x19\n\x11versioning_scheme\x18\x06 \x01(\t\x12\x1a\n\x12version_query_name\x18\x07 \x01(\t\"X\n\x0fServiceApisTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xb6\x01\n\x1aServiceApisTagDescriptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12!\n\x19\x65xternal_docs_description\x18\x04 \x01(\t\x12\x19\n\x11\x65xternal_docs_url\x18\x05 \x01(\t\"\xc8\x01\n\x12ServiceApisSchemas\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x03 \x01(\t\x12U\n\x08\x64ocument\x18\x04 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_apimanagement.SchemaDocumentProperties\"\xe4\x02\n\x18SchemaDocumentProperties\x12g\n\ncomponents\x18\x01 \x03(\x0b\x32S.oak9.tython.azure.microsoft_apimanagement.SchemaDocumentProperties.ComponentsEntry\x12i\n\x0b\x64\x65\x66initions\x18\x02 \x03(\x0b\x32T.oak9.tython.azure.microsoft_apimanagement.SchemaDocumentProperties.DefinitionsEntry\x12\r\n\x05value\x18\x03 \x01(\t\x1a\x31\n\x0f\x43omponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x44\x65\x66initionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x13ServiceApisReleases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x03 \x01(\t\x12\r\n\x05notes\x18\x04 \x01(\t\"{\n\x13ServiceApisPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"b\n\x19ServiceApisOperationsTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x1dServiceApisOperationsPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"\xb9\x03\n\x15ServiceApisOperations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x0e\n\x06method\x18\x05 \x01(\t\x12\x10\n\x08policies\x18\x06 \x01(\t\x12K\n\x07request\x18\x07 \x01(\x0b\x32:.oak9.tython.azure.microsoft_apimanagement.RequestContract\x12N\n\tresponses\x18\x08 \x03(\x0b\x32;.oak9.tython.azure.microsoft_apimanagement.ResponseContract\x12Y\n\x13template_parameters\x18\t \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.ParameterContract\x12\x14\n\x0curl_template\x18\n \x01(\t\"\xe7\x01\n\x10ResponseContract\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12M\n\x07headers\x18\x02 \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.ParameterContract\x12Z\n\x0frepresentations\x18\x03 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_apimanagement.RepresentationContract\x12\x13\n\x0bstatus_code\x18\x04 \x01(\x05\"\xa9\x02\n\x0fRequestContract\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12M\n\x07headers\x18\x02 \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.ParameterContract\x12V\n\x10query_parameters\x18\x03 \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.ParameterContract\x12Z\n\x0frepresentations\x18\x04 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_apimanagement.RepresentationContract\"\xbf\x02\n\x16RepresentationContract\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x61\n\x08\x65xamples\x18\x02 \x03(\x0b\x32O.oak9.tython.azure.microsoft_apimanagement.RepresentationContract.ExamplesEntry\x12U\n\x0f\x66orm_parameters\x18\x03 \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.ParameterContract\x12\x11\n\tschema_id\x18\x04 \x01(\t\x12\x11\n\ttype_name\x18\x05 \x01(\t\x1a/\n\rExamplesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x02\n\x11ParameterContract\x12\x15\n\rdefault_value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\\\n\x08\x65xamples\x18\x03 \x03(\x0b\x32J.oak9.tython.azure.microsoft_apimanagement.ParameterContract.ExamplesEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\x11\n\tschema_id\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\x12\x11\n\ttype_name\x18\x08 \x01(\t\x12\x0e\n\x06values\x18\t \x03(\t\x1a/\n\rExamplesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x19ServiceApisIssuesComments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x63reated_date\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\"\x9d\x01\n\x1cServiceApisIssuesAttachments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x16\n\x0e\x63ontent_format\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\"\xa2\x03\n\x11ServiceApisIssues\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x03 \x01(\t\x12\x14\n\x0c\x63reated_date\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07user_id\x18\x08 \x01(\t\x12j\n\x1cservice_apis_issues_comments\x18\t \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_apimanagement.ServiceApisIssuesComments\x12p\n\x1fservice_apis_issues_attachments\x18\n \x03(\x0b\x32G.oak9.tython.azure.microsoft_apimanagement.ServiceApisIssuesAttachments\"\xf2\x03\n\x16ServiceApisDiagnostics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nalways_log\x18\x03 \x01(\t\x12V\n\x07\x62\x61\x63kend\x18\x04 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_apimanagement.PipelineDiagnosticSettings\x12W\n\x08\x66rontend\x18\x05 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_apimanagement.PipelineDiagnosticSettings\x12!\n\x19http_correlation_protocol\x18\x06 \x01(\t\x12\x15\n\rlog_client_ip\x18\x07 \x01(\x08\x12\x11\n\tlogger_id\x18\x08 \x01(\t\x12\x1d\n\x15operation_name_format\x18\t \x01(\t\x12M\n\x08sampling\x18\n \x01(\x0b\x32;.oak9.tython.azure.microsoft_apimanagement.SamplingSettings\x12\x11\n\tverbosity\x18\x0b \x01(\t\"=\n\x10SamplingSettings\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x15\n\rsampling_type\x18\x02 \x01(\t\"\xc3\x01\n\x1aPipelineDiagnosticSettings\x12Q\n\x07request\x18\x01 \x01(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.HttpMessageDiagnostic\x12R\n\x08response\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.HttpMessageDiagnostic\"\xc7\x01\n\x15HttpMessageDiagnostic\x12O\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_apimanagement.BodyDiagnosticSettings\x12L\n\x0c\x64\x61ta_masking\x18\x02 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_apimanagement.DataMasking\x12\x0f\n\x07headers\x18\x03 \x03(\t\"\xb0\x01\n\x0b\x44\x61taMasking\x12M\n\x07headers\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.DataMaskingEntity\x12R\n\x0cquery_params\x18\x02 \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.DataMaskingEntity\"0\n\x11\x44\x61taMaskingEntity\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\'\n\x16\x42odyDiagnosticSettings\x12\r\n\x05\x62ytes\x18\x01 \x01(\x05\"\xc3\n\n\x0bServiceApis\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x61pi_revision\x18\x03 \x01(\t\x12 \n\x18\x61pi_revision_description\x18\x04 \x01(\t\x12\x10\n\x08\x61pi_type\x18\x05 \x01(\t\x12\x1f\n\x17\x61pi_version_description\x18\x06 \x01(\t\x12`\n\x0f\x61pi_version_set\x18\x07 \x01(\x0b\x32G.oak9.tython.azure.microsoft_apimanagement.ApiVersionSetContractDetails\x12\x1a\n\x12\x61pi_version_set_id\x18\x08 \x01(\t\x12j\n\x17\x61uthentication_settings\x18\t \x01(\x0b\x32I.oak9.tython.azure.microsoft_apimanagement.AuthenticationSettingsContract\x12Q\n\x07\x63ontact\x18\n \x01(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.ApiContactInformation\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x0c \x01(\t\x12\x0e\n\x06\x66ormat\x18\r \x01(\t\x12\x12\n\nis_current\x18\x0e \x01(\x08\x12Q\n\x07license\x18\x0f \x01(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.ApiLicenseInformation\x12\x0c\n\x04path\x18\x10 \x01(\t\x12\x11\n\tprotocols\x18\x11 \x03(\t\x12\x13\n\x0bservice_url\x18\x12 \x01(\t\x12\x15\n\rsource_api_id\x18\x13 \x01(\t\x12z\n subscription_key_parameter_names\x18\x14 \x01(\x0b\x32P.oak9.tython.azure.microsoft_apimanagement.SubscriptionKeyParameterNamesContract\x12\x1d\n\x15subscription_required\x18\x15 \x01(\x08\x12\x1c\n\x14terms_of_service_url\x18\x16 \x01(\t\x12\x0c\n\x04type\x18\x17 \x01(\t\x12\r\n\x05value\x18\x18 \x01(\t\x12i\n\rwsdl_selector\x18\x19 \x01(\x0b\x32R.oak9.tython.azure.microsoft_apimanagement.ApiCreateOrUpdatePropertiesWsdlSelector\x12]\n\x15service_apis_releases\x18\x1a \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.ServiceApisReleases\x12[\n\x14service_apis_schemas\x18\x1b \x03(\x0b\x32=.oak9.tython.azure.microsoft_apimanagement.ServiceApisSchemas\x12Y\n\x13service_apis_issues\x18\x1c \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.ServiceApisIssues\"`\n\'ApiCreateOrUpdatePropertiesWsdlSelector\x12\x1a\n\x12wsdl_endpoint_name\x18\x01 \x01(\t\x12\x19\n\x11wsdl_service_name\x18\x02 \x01(\t\"F\n%SubscriptionKeyParameterNamesContract\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\"2\n\x15\x41piLicenseInformation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"A\n\x15\x41piContactInformation\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"\xe3\x01\n\x1e\x41uthenticationSettingsContract\x12`\n\x07o_auth2\x18\x01 \x01(\x0b\x32O.oak9.tython.azure.microsoft_apimanagement.OAuth2AuthenticationSettingsContract\x12_\n\x06openid\x18\x02 \x01(\x0b\x32O.oak9.tython.azure.microsoft_apimanagement.OpenIdAuthenticationSettingsContract\"h\n$OpenIdAuthenticationSettingsContract\x12$\n\x1c\x62\x65\x61rer_token_sending_methods\x18\x01 \x03(\t\x12\x1a\n\x12openid_provider_id\x18\x02 \x01(\t\"V\n$OAuth2AuthenticationSettingsContract\x12\x1f\n\x17\x61uthorization_server_id\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\"\xa1\x01\n\x1c\x41piVersionSetContractDetails\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13version_header_name\x18\x04 \x01(\t\x12\x19\n\x11versioning_scheme\x18\x05 \x01(\t\x12\x1a\n\x12version_query_name\x18\x06 \x01(\t\"\xde\x11\n\x07Service\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x08identity\x18\x02 \x01(\x0b\x32G.oak9.tython.azure.microsoft_apimanagement.ApiManagementServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12[\n\x14\x61\x64\x64itional_locations\x18\x05 \x03(\x0b\x32=.oak9.tython.azure.microsoft_apimanagement.AdditionalLocation\x12_\n\x16\x61pi_version_constraint\x18\x06 \x01(\x0b\x32?.oak9.tython.azure.microsoft_apimanagement.ApiVersionConstraint\x12Y\n\x0c\x63\x65rtificates\x18\x07 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_apimanagement.CertificateConfiguration\x12\x63\n\x11\x63ustom_properties\x18\x08 \x03(\x0b\x32H.oak9.tython.azure.microsoft_apimanagement.Service.CustomPropertiesEntry\x12\x17\n\x0f\x64isable_gateway\x18\t \x01(\x08\x12!\n\x19\x65nable_client_certificate\x18\n \x01(\x08\x12\x61\n\x17hostname_configurations\x18\x0b \x03(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.HostnameConfiguration\x12!\n\x19notification_sender_email\x18\x0c \x01(\t\x12w\n\x1cprivate_endpoint_connections\x18\r \x03(\x0b\x32Q.oak9.tython.azure.microsoft_apimanagement.RemotePrivateEndpointConnectionWrapper\x12\x1c\n\x14public_ip_address_id\x18\x0e \x01(\t\x12\x1d\n\x15public_network_access\x18\x0f \x01(\t\x12\x17\n\x0fpublisher_email\x18\x10 \x01(\t\x12\x16\n\x0epublisher_name\x18\x11 \x01(\t\x12\x0f\n\x07restore\x18\x12 \x01(\x08\x12m\n\x1dvirtual_network_configuration\x18\x13 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_apimanagement.VirtualNetworkConfiguration\x12\x1c\n\x14virtual_network_type\x18\x14 \x01(\t\x12Y\n\x03sku\x18\x15 \x01(\x0b\x32L.oak9.tython.azure.microsoft_apimanagement.ApiManagementServiceSkuProperties\x12J\n\x04tags\x18\x16 \x03(\x0b\x32<.oak9.tython.azure.microsoft_apimanagement.Service.TagsEntry\x12\r\n\x05zones\x18\x17 \x03(\t\x12L\n\x0cservice_tags\x18\x18 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_apimanagement.ServiceTags\x12P\n\x0eservice_caches\x18\x19 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_apimanagement.ServiceCaches\x12]\n\x15service_content_types\x18\x1a \x03(\x0b\x32>.oak9.tython.azure.microsoft_apimanagement.ServiceContentTypes\x12V\n\x11service_templates\x18\x1b \x03(\x0b\x32;.oak9.tython.azure.microsoft_apimanagement.ServiceTemplates\x12\x63\n\x18service_portal_revisions\x18\x1c \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_apimanagement.ServicePortalRevisions\x12`\n\x16service_portalsettings\x18\x1d \x03(\x0b\x32@.oak9.tython.azure.microsoft_apimanagement.ServicePortalsettings\x12z\n$service_private_endpoint_connections\x18\x1e \x03(\x0b\x32L.oak9.tython.azure.microsoft_apimanagement.ServicePrivateEndpointConnections\x12R\n\x0fservice_schemas\x18\x1f \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_apimanagement.ServiceSchemas\x12P\n\x0eservice_tenant\x18  \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_apimanagement.ServiceTenant\x1a\x37\n\x15\x43ustomPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x02\n&RemotePrivateEndpointConnectionWrapper\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\x10private_endpoint\x18\x03 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_apimanagement.ArmIdWrapper\x12{\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32L.oak9.tython.azure.microsoft_apimanagement.PrivateLinkServiceConnectionState\x12\x0c\n\x04type\x18\x05 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1c\n\x0c\x41rmIdWrapper\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf8\x02\n\x15HostnameConfiguration\x12V\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_apimanagement.CertificateInformation\x12\x1c\n\x14\x63\x65rtificate_password\x18\x02 \x01(\t\x12\x1a\n\x12\x63\x65rtificate_source\x18\x03 \x01(\t\x12\x1a\n\x12\x63\x65rtificate_status\x18\x04 \x01(\t\x12\x1b\n\x13\x64\x65\x66\x61ult_ssl_binding\x18\x05 \x01(\x08\x12\x1b\n\x13\x65ncoded_certificate\x18\x06 \x01(\t\x12\x11\n\thost_name\x18\x07 \x01(\t\x12\x1a\n\x12identity_client_id\x18\x08 \x01(\t\x12\x14\n\x0ckey_vault_id\x18\t \x01(\t\x12$\n\x1cnegotiate_client_certificate\x18\n \x01(\x08\x12\x0c\n\x04type\x18\x0b \x01(\t\"\xc1\x01\n\x18\x43\x65rtificateConfiguration\x12V\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_apimanagement.CertificateInformation\x12\x1c\n\x14\x63\x65rtificate_password\x18\x02 \x01(\t\x12\x1b\n\x13\x65ncoded_certificate\x18\x03 \x01(\t\x12\x12\n\nstore_name\x18\x04 \x01(\t\"M\n\x16\x43\x65rtificateInformation\x12\x0e\n\x06\x65xpiry\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x12\n\nthumbprint\x18\x03 \x01(\t\"/\n\x14\x41piVersionConstraint\x12\x17\n\x0fmin_api_version\x18\x01 \x01(\t\"\xb6\x02\n\x12\x41\x64\x64itionalLocation\x12\x17\n\x0f\x64isable_gateway\x18\x01 \x01(\x08\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x1c\n\x14public_ip_address_id\x18\x03 \x01(\t\x12Y\n\x03sku\x18\x04 \x01(\x0b\x32L.oak9.tython.azure.microsoft_apimanagement.ApiManagementServiceSkuProperties\x12m\n\x1dvirtual_network_configuration\x18\x05 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_apimanagement.VirtualNetworkConfiguration\x12\r\n\x05zones\x18\x06 \x03(\t\"9\n\x1bVirtualNetworkConfiguration\x12\x1a\n\x12subnet_resource_id\x18\x01 \x01(\t\"C\n!ApiManagementServiceSkuProperties\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xf3\x01\n\x1c\x41piManagementServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x85\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_apimanagement.ApiManagementServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_apimanagement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVICESCHEMAS_DOCUMENTENTRY._options = None
  _SERVICESCHEMAS_DOCUMENTENTRY._serialized_options = b'8\001'
  _SERVICESCHEMAS_VALUEENTRY._options = None
  _SERVICESCHEMAS_VALUEENTRY._serialized_options = b'8\001'
  _SERVICELOGGERS_CREDENTIALSENTRY._options = None
  _SERVICELOGGERS_CREDENTIALSENTRY._serialized_options = b'8\001'
  _BACKENDCREDENTIALSCONTRACT_HEADERENTRY._options = None
  _BACKENDCREDENTIALSCONTRACT_HEADERENTRY._serialized_options = b'8\001'
  _BACKENDCREDENTIALSCONTRACT_QUERYENTRY._options = None
  _BACKENDCREDENTIALSCONTRACT_QUERYENTRY._serialized_options = b'8\001'
  _SCHEMADOCUMENTPROPERTIES_COMPONENTSENTRY._options = None
  _SCHEMADOCUMENTPROPERTIES_COMPONENTSENTRY._serialized_options = b'8\001'
  _SCHEMADOCUMENTPROPERTIES_DEFINITIONSENTRY._options = None
  _SCHEMADOCUMENTPROPERTIES_DEFINITIONSENTRY._serialized_options = b'8\001'
  _REPRESENTATIONCONTRACT_EXAMPLESENTRY._options = None
  _REPRESENTATIONCONTRACT_EXAMPLESENTRY._serialized_options = b'8\001'
  _PARAMETERCONTRACT_EXAMPLESENTRY._options = None
  _PARAMETERCONTRACT_EXAMPLESENTRY._serialized_options = b'8\001'
  _SERVICE_CUSTOMPROPERTIESENTRY._options = None
  _SERVICE_CUSTOMPROPERTIESENTRY._serialized_options = b'8\001'
  _SERVICE_TAGSENTRY._options = None
  _SERVICE_TAGSENTRY._serialized_options = b'8\001'
  _APIMANAGEMENTSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _APIMANAGEMENTSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_APIMANAGEMENT._serialized_start=110
  _MICROSOFT_APIMANAGEMENT._serialized_end=2812
  _SERVICEUSERS._serialized_start=2815
  _SERVICEUSERS._serialized_end=3126
  _USERIDENTITYCONTRACT._serialized_start=3128
  _USERIDENTITYCONTRACT._serialized_end=3180
  _SERVICETENANT._serialized_start=3183
  _SERVICETENANT._serialized_end=3352
  _SERVICETEMPLATES._serialized_start=3355
  _SERVICETEMPLATES._serialized_end=3617
  _EMAILTEMPLATEPARAMETERSCONTRACTPROPERTIES._serialized_start=3619
  _EMAILTEMPLATEPARAMETERSCONTRACTPROPERTIES._serialized_end=3712
  _SERVICETAGS._serialized_start=3714
  _SERVICETAGS._serialized_end=3820
  _SERVICESUBSCRIPTIONS._serialized_start=3823
  _SERVICESUBSCRIPTIONS._serialized_end=4053
  _SERVICESCHEMAS._serialized_start=4056
  _SERVICESCHEMAS._serialized_end=4456
  _SERVICESCHEMAS_DOCUMENTENTRY._serialized_start=4363
  _SERVICESCHEMAS_DOCUMENTENTRY._serialized_end=4410
  _SERVICESCHEMAS_VALUEENTRY._serialized_start=4412
  _SERVICESCHEMAS_VALUEENTRY._serialized_end=4456
  _SERVICEPRODUCTSTAGS._serialized_start=4458
  _SERVICEPRODUCTSTAGS._serialized_end=4550
  _SERVICEPRODUCTSPOLICIES._serialized_start=4552
  _SERVICEPRODUCTSPOLICIES._serialized_end=4679
  _SERVICEPRODUCTSGROUPS._serialized_start=4681
  _SERVICEPRODUCTSGROUPS._serialized_end=4775
  _SERVICEPRODUCTSAPIS._serialized_start=4777
  _SERVICEPRODUCTSAPIS._serialized_end=4869
  _SERVICEPRODUCTS._serialized_start=4872
  _SERVICEPRODUCTS._serialized_end=5512
  _SERVICEPRIVATEENDPOINTCONNECTIONS._serialized_start=5515
  _SERVICEPRIVATEENDPOINTCONNECTIONS._serialized_end=5758
  _SERVICEPORTALSETTINGS._serialized_start=5760
  _SERVICEPORTALSETTINGS._serialized_end=5840
  _SERVICEPORTALREVISIONS._serialized_start=5843
  _SERVICEPORTALREVISIONS._serialized_end=5979
  _SERVICEPOLICIES._serialized_start=5981
  _SERVICEPOLICIES._serialized_end=6100
  _SERVICEOPENIDCONNECTPROVIDERS._serialized_start=6103
  _SERVICEOPENIDCONNECTPROVIDERS._serialized_end=6317
  _SERVICENOTIFICATIONSRECIPIENTUSERS._serialized_start=6319
  _SERVICENOTIFICATIONSRECIPIENTUSERS._serialized_end=6426
  _SERVICENOTIFICATIONSRECIPIENTEMAILS._serialized_start=6428
  _SERVICENOTIFICATIONSRECIPIENTEMAILS._serialized_end=6536
  _SERVICENOTIFICATIONS._serialized_start=6539
  _SERVICENOTIFICATIONS._serialized_end=6886
  _SERVICENAMEDVALUES._serialized_start=6889
  _SERVICENAMEDVALUES._serialized_end=7143
  _SERVICELOGGERS._serialized_start=7146
  _SERVICELOGGERS._serialized_end=7466
  _SERVICELOGGERS_CREDENTIALSENTRY._serialized_start=7416
  _SERVICELOGGERS_CREDENTIALSENTRY._serialized_end=7466
  _SERVICEIDENTITYPROVIDERS._serialized_start=7469
  _SERVICEIDENTITYPROVIDERS._serialized_end=7818
  _SERVICEGROUPSUSERS._serialized_start=7820
  _SERVICEGROUPSUSERS._serialized_end=7911
  _SERVICEGROUPS._serialized_start=7914
  _SERVICEGROUPS._serialized_end=8078
  _SERVICEGATEWAYSHOSTNAMECONFIGURATIONS._serialized_start=8081
  _SERVICEGATEWAYSHOSTNAMECONFIGURATIONS._serialized_end=8340
  _SERVICEGATEWAYSCERTIFICATEAUTHORITIES._serialized_start=8343
  _SERVICEGATEWAYSCERTIFICATEAUTHORITIES._serialized_end=8473
  _SERVICEGATEWAYSAPIS._serialized_start=8475
  _SERVICEGATEWAYSAPIS._serialized_end=8595
  _SERVICEGATEWAYS._serialized_start=8598
  _SERVICEGATEWAYS._serialized_end=8936
  _RESOURCELOCATIONDATACONTRACT._serialized_start=8938
  _RESOURCELOCATIONDATACONTRACT._serialized_end=9041
  _SERVICEDIAGNOSTICS._serialized_start=9044
  _SERVICEDIAGNOSTICS._serialized_end=9538
  _SERVICECONTENTTYPESCONTENTITEMS._serialized_start=9540
  _SERVICECONTENTTYPESCONTENTITEMS._serialized_end=9644
  _SERVICECONTENTTYPES._serialized_start=9647
  _SERVICECONTENTTYPES._serialized_end=9860
  _SERVICECERTIFICATES._serialized_start=9863
  _SERVICECERTIFICATES._serialized_end=10083
  _KEYVAULTCONTRACTCREATEPROPERTIES._serialized_start=10085
  _KEYVAULTCONTRACTCREATEPROPERTIES._serialized_end=10174
  _SERVICECACHES._serialized_start=10177
  _SERVICECACHES._serialized_end=10359
  _SERVICEBACKENDS._serialized_start=10362
  _SERVICEBACKENDS._serialized_end=10902
  _BACKENDTLSPROPERTIES._serialized_start=10904
  _BACKENDTLSPROPERTIES._serialized_end=10997
  _BACKENDPROXYCONTRACT._serialized_start=10999
  _BACKENDPROXYCONTRACT._serialized_end=11070
  _BACKENDSERVICEFABRICCLUSTERPROPERTIES._serialized_start=11073
  _BACKENDSERVICEFABRICCLUSTERPROPERTIES._serialized_end=11384
  _X509CERTIFICATENAME._serialized_start=11386
  _X509CERTIFICATENAME._serialized_end=11460
  _BACKENDCREDENTIALSCONTRACT._serialized_start=11463
  _BACKENDCREDENTIALSCONTRACT._serialized_end=11931
  _BACKENDCREDENTIALSCONTRACT_HEADERENTRY._serialized_start=11840
  _BACKENDCREDENTIALSCONTRACT_HEADERENTRY._serialized_end=11885
  _BACKENDCREDENTIALSCONTRACT_QUERYENTRY._serialized_start=11887
  _BACKENDCREDENTIALSCONTRACT_QUERYENTRY._serialized_end=11931
  _BACKENDAUTHORIZATIONHEADERCREDENTIALS._serialized_start=11933
  _BACKENDAUTHORIZATIONHEADERCREDENTIALS._serialized_end=12007
  _SERVICEAUTHORIZATIONSERVERS._serialized_start=12010
  _SERVICEAUTHORIZATIONSERVERS._serialized_end=12631
  _TOKENBODYPARAMETERCONTRACT._serialized_start=12633
  _TOKENBODYPARAMETERCONTRACT._serialized_end=12690
  _SERVICEAPIVERSIONSETS._serialized_start=12693
  _SERVICEAPIVERSIONSETS._serialized_end=12914
  _SERVICEAPISTAGS._serialized_start=12916
  _SERVICEAPISTAGS._serialized_end=13004
  _SERVICEAPISTAGDESCRIPTIONS._serialized_start=13007
  _SERVICEAPISTAGDESCRIPTIONS._serialized_end=13189
  _SERVICEAPISSCHEMAS._serialized_start=13192
  _SERVICEAPISSCHEMAS._serialized_end=13392
  _SCHEMADOCUMENTPROPERTIES._serialized_start=13395
  _SCHEMADOCUMENTPROPERTIES._serialized_end=13751
  _SCHEMADOCUMENTPROPERTIES_COMPONENTSENTRY._serialized_start=13650
  _SCHEMADOCUMENTPROPERTIES_COMPONENTSENTRY._serialized_end=13699
  _SCHEMADOCUMENTPROPERTIES_DEFINITIONSENTRY._serialized_start=13701
  _SCHEMADOCUMENTPROPERTIES_DEFINITIONSENTRY._serialized_end=13751
  _SERVICEAPISRELEASES._serialized_start=13753
  _SERVICEAPISRELEASES._serialized_end=13876
  _SERVICEAPISPOLICIES._serialized_start=13878
  _SERVICEAPISPOLICIES._serialized_end=14001
  _SERVICEAPISOPERATIONSTAGS._serialized_start=14003
  _SERVICEAPISOPERATIONSTAGS._serialized_end=14101
  _SERVICEAPISOPERATIONSPOLICIES._serialized_start=14104
  _SERVICEAPISOPERATIONSPOLICIES._serialized_end=14237
  _SERVICEAPISOPERATIONS._serialized_start=14240
  _SERVICEAPISOPERATIONS._serialized_end=14681
  _RESPONSECONTRACT._serialized_start=14684
  _RESPONSECONTRACT._serialized_end=14915
  _REQUESTCONTRACT._serialized_start=14918
  _REQUESTCONTRACT._serialized_end=15215
  _REPRESENTATIONCONTRACT._serialized_start=15218
  _REPRESENTATIONCONTRACT._serialized_end=15537
  _REPRESENTATIONCONTRACT_EXAMPLESENTRY._serialized_start=15490
  _REPRESENTATIONCONTRACT_EXAMPLESENTRY._serialized_end=15537
  _PARAMETERCONTRACT._serialized_start=15540
  _PARAMETERCONTRACT._serialized_end=15846
  _PARAMETERCONTRACT_EXAMPLESENTRY._serialized_start=15490
  _PARAMETERCONTRACT_EXAMPLESENTRY._serialized_end=15537
  _SERVICEAPISISSUESCOMMENTS._serialized_start=15849
  _SERVICEAPISISSUESCOMMENTS._serialized_end=16000
  _SERVICEAPISISSUESATTACHMENTS._serialized_start=16003
  _SERVICEAPISISSUESATTACHMENTS._serialized_end=16160
  _SERVICEAPISISSUES._serialized_start=16163
  _SERVICEAPISISSUES._serialized_end=16581
  _SERVICEAPISDIAGNOSTICS._serialized_start=16584
  _SERVICEAPISDIAGNOSTICS._serialized_end=17082
  _SAMPLINGSETTINGS._serialized_start=17084
  _SAMPLINGSETTINGS._serialized_end=17145
  _PIPELINEDIAGNOSTICSETTINGS._serialized_start=17148
  _PIPELINEDIAGNOSTICSETTINGS._serialized_end=17343
  _HTTPMESSAGEDIAGNOSTIC._serialized_start=17346
  _HTTPMESSAGEDIAGNOSTIC._serialized_end=17545
  _DATAMASKING._serialized_start=17548
  _DATAMASKING._serialized_end=17724
  _DATAMASKINGENTITY._serialized_start=17726
  _DATAMASKINGENTITY._serialized_end=17774
  _BODYDIAGNOSTICSETTINGS._serialized_start=17776
  _BODYDIAGNOSTICSETTINGS._serialized_end=17815
  _SERVICEAPIS._serialized_start=17818
  _SERVICEAPIS._serialized_end=19165
  _APICREATEORUPDATEPROPERTIESWSDLSELECTOR._serialized_start=19167
  _APICREATEORUPDATEPROPERTIESWSDLSELECTOR._serialized_end=19263
  _SUBSCRIPTIONKEYPARAMETERNAMESCONTRACT._serialized_start=19265
  _SUBSCRIPTIONKEYPARAMETERNAMESCONTRACT._serialized_end=19335
  _APILICENSEINFORMATION._serialized_start=19337
  _APILICENSEINFORMATION._serialized_end=19387
  _APICONTACTINFORMATION._serialized_start=19389
  _APICONTACTINFORMATION._serialized_end=19454
  _AUTHENTICATIONSETTINGSCONTRACT._serialized_start=19457
  _AUTHENTICATIONSETTINGSCONTRACT._serialized_end=19684
  _OPENIDAUTHENTICATIONSETTINGSCONTRACT._serialized_start=19686
  _OPENIDAUTHENTICATIONSETTINGSCONTRACT._serialized_end=19790
  _OAUTH2AUTHENTICATIONSETTINGSCONTRACT._serialized_start=19792
  _OAUTH2AUTHENTICATIONSETTINGSCONTRACT._serialized_end=19878
  _APIVERSIONSETCONTRACTDETAILS._serialized_start=19881
  _APIVERSIONSETCONTRACTDETAILS._serialized_end=20042
  _SERVICE._serialized_start=20045
  _SERVICE._serialized_end=22315
  _SERVICE_CUSTOMPROPERTIESENTRY._serialized_start=22215
  _SERVICE_CUSTOMPROPERTIESENTRY._serialized_end=22270
  _SERVICE_TAGSENTRY._serialized_start=22272
  _SERVICE_TAGSENTRY._serialized_end=22315
  _REMOTEPRIVATEENDPOINTCONNECTIONWRAPPER._serialized_start=22318
  _REMOTEPRIVATEENDPOINTCONNECTIONWRAPPER._serialized_end=22606
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=22608
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=22706
  _ARMIDWRAPPER._serialized_start=22708
  _ARMIDWRAPPER._serialized_end=22736
  _HOSTNAMECONFIGURATION._serialized_start=22739
  _HOSTNAMECONFIGURATION._serialized_end=23115
  _CERTIFICATECONFIGURATION._serialized_start=23118
  _CERTIFICATECONFIGURATION._serialized_end=23311
  _CERTIFICATEINFORMATION._serialized_start=23313
  _CERTIFICATEINFORMATION._serialized_end=23390
  _APIVERSIONCONSTRAINT._serialized_start=23392
  _APIVERSIONCONSTRAINT._serialized_end=23439
  _ADDITIONALLOCATION._serialized_start=23442
  _ADDITIONALLOCATION._serialized_end=23752
  _VIRTUALNETWORKCONFIGURATION._serialized_start=23754
  _VIRTUALNETWORKCONFIGURATION._serialized_end=23811
  _APIMANAGEMENTSERVICESKUPROPERTIES._serialized_start=23813
  _APIMANAGEMENTSERVICESKUPROPERTIES._serialized_end=23880
  _APIMANAGEMENTSERVICEIDENTITY._serialized_start=23883
  _APIMANAGEMENTSERVICEIDENTITY._serialized_end=24126
  _APIMANAGEMENTSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=24065
  _APIMANAGEMENTSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=24126
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Cache(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDIS_FIELD_NUMBER: builtins.int
    REDIS_FIREWALL_RULES_FIELD_NUMBER: builtins.int
    REDIS_LINKED_SERVERS_FIELD_NUMBER: builtins.int
    REDIS_PATCH_SCHEDULES_FIELD_NUMBER: builtins.int
    @property
    def redis(self) -> global___Redis: ...
    @property
    def redis_firewall_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RedisFirewallRules]: ...
    @property
    def redis_linked_servers(self) -> global___RedisLinkedServers: ...
    @property
    def redis_patch_schedules(self) -> global___RedisPatchSchedules: ...
    def __init__(
        self,
        *,
        redis: global___Redis | None = ...,
        redis_firewall_rules: collections.abc.Iterable[global___RedisFirewallRules] | None = ...,
        redis_linked_servers: global___RedisLinkedServers | None = ...,
        redis_patch_schedules: global___RedisPatchSchedules | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["redis", b"redis", "redis_linked_servers", b"redis_linked_servers", "redis_patch_schedules", b"redis_patch_schedules"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["redis", b"redis", "redis_firewall_rules", b"redis_firewall_rules", "redis_linked_servers", b"redis_linked_servers", "redis_patch_schedules", b"redis_patch_schedules"]) -> None: ...

global___Microsoft_Cache = Microsoft_Cache

@typing_extensions.final
class RedisPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___RedisPrivateEndpointConnections = RedisPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class RedisPatchSchedules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULE_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def schedule_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ScheduleEntry]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        schedule_entries: collections.abc.Iterable[global___ScheduleEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "schedule_entries", b"schedule_entries"]) -> None: ...

global___RedisPatchSchedules = RedisPatchSchedules

@typing_extensions.final
class ScheduleEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    START_HOUR_UTC_FIELD_NUMBER: builtins.int
    day_of_week: builtins.str
    maintenance_window: builtins.str
    start_hour_utc: builtins.int
    def __init__(
        self,
        *,
        day_of_week: builtins.str = ...,
        maintenance_window: builtins.str = ...,
        start_hour_utc: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week", "maintenance_window", b"maintenance_window", "start_hour_utc", b"start_hour_utc"]) -> None: ...

global___ScheduleEntry = ScheduleEntry

@typing_extensions.final
class RedisLinkedServers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LINKED_REDIS_CACHE_ID_FIELD_NUMBER: builtins.int
    LINKED_REDIS_CACHE_LOCATION_FIELD_NUMBER: builtins.int
    SERVER_ROLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    linked_redis_cache_id: builtins.str
    linked_redis_cache_location: builtins.str
    server_role: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        linked_redis_cache_id: builtins.str = ...,
        linked_redis_cache_location: builtins.str = ...,
        server_role: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["linked_redis_cache_id", b"linked_redis_cache_id", "linked_redis_cache_location", b"linked_redis_cache_location", "name", b"name", "resource_info", b"resource_info", "server_role", b"server_role"]) -> None: ...

global___RedisLinkedServers = RedisLinkedServers

@typing_extensions.final
class RedisFirewallRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    END_IP_FIELD_NUMBER: builtins.int
    START_IP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    end_ip: builtins.str
    start_ip: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        end_ip: builtins.str = ...,
        start_ip: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_ip", b"end_ip", "name", b"name", "resource_info", b"resource_info", "start_ip", b"start_ip"]) -> None: ...

global___RedisFirewallRules = RedisFirewallRules

@typing_extensions.final
class Redis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TenantSettingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLE_NON_SSL_PORT_FIELD_NUMBER: builtins.int
    MINIMUM_TLS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    REDIS_CONFIGURATION_FIELD_NUMBER: builtins.int
    REDIS_VERSION_FIELD_NUMBER: builtins.int
    REPLICAS_PER_MASTER_FIELD_NUMBER: builtins.int
    REPLICAS_PER_PRIMARY_FIELD_NUMBER: builtins.int
    SHARD_COUNT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    STATIC_IP_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    TENANT_SETTINGS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    REDIS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    enable_non_ssl_port: builtins.bool
    minimum_tls_version: builtins.str
    public_network_access: builtins.str
    @property
    def redis_configuration(self) -> global___RedisCommonPropertiesRedisConfiguration: ...
    redis_version: builtins.str
    replicas_per_master: builtins.int
    replicas_per_primary: builtins.int
    shard_count: builtins.int
    @property
    def sku(self) -> global___Sku: ...
    static_ip: builtins.str
    subnet_id: builtins.str
    @property
    def tenant_settings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def redis_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RedisPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        enable_non_ssl_port: builtins.bool = ...,
        minimum_tls_version: builtins.str = ...,
        public_network_access: builtins.str = ...,
        redis_configuration: global___RedisCommonPropertiesRedisConfiguration | None = ...,
        redis_version: builtins.str = ...,
        replicas_per_master: builtins.int = ...,
        replicas_per_primary: builtins.int = ...,
        shard_count: builtins.int = ...,
        sku: global___Sku | None = ...,
        static_ip: builtins.str = ...,
        subnet_id: builtins.str = ...,
        tenant_settings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        redis_private_endpoint_connections: collections.abc.Iterable[global___RedisPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "redis_configuration", b"redis_configuration", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_non_ssl_port", b"enable_non_ssl_port", "identity", b"identity", "location", b"location", "minimum_tls_version", b"minimum_tls_version", "name", b"name", "public_network_access", b"public_network_access", "redis_configuration", b"redis_configuration", "redis_private_endpoint_connections", b"redis_private_endpoint_connections", "redis_version", b"redis_version", "replicas_per_master", b"replicas_per_master", "replicas_per_primary", b"replicas_per_primary", "resource_info", b"resource_info", "shard_count", b"shard_count", "sku", b"sku", "static_ip", b"static_ip", "subnet_id", b"subnet_id", "tags", b"tags", "tenant_settings", b"tenant_settings", "zones", b"zones"]) -> None: ...

global___Redis = Redis

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    family: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class RedisCommonPropertiesRedisConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AdditionalPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    AOF_STORAGE_CONNECTION_STRING_0_FIELD_NUMBER: builtins.int
    AOF_STORAGE_CONNECTION_STRING_1_FIELD_NUMBER: builtins.int
    MAXFRAGMENTATIONMEMORY_RESERVED_FIELD_NUMBER: builtins.int
    MAXMEMORY_DELTA_FIELD_NUMBER: builtins.int
    MAXMEMORY_POLICY_FIELD_NUMBER: builtins.int
    MAXMEMORY_RESERVED_FIELD_NUMBER: builtins.int
    RDB_BACKUP_ENABLED_FIELD_NUMBER: builtins.int
    RDB_BACKUP_FREQUENCY_FIELD_NUMBER: builtins.int
    RDB_BACKUP_MAX_SNAPSHOT_COUNT_FIELD_NUMBER: builtins.int
    RDB_STORAGE_CONNECTION_STRING_FIELD_NUMBER: builtins.int
    @property
    def additional_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    aof_storage_connection_string_0: builtins.str
    aof_storage_connection_string_1: builtins.str
    maxfragmentationmemory_reserved: builtins.str
    maxmemory_delta: builtins.str
    maxmemory_policy: builtins.str
    maxmemory_reserved: builtins.str
    rdb_backup_enabled: builtins.str
    rdb_backup_frequency: builtins.str
    rdb_backup_max_snapshot_count: builtins.str
    rdb_storage_connection_string: builtins.str
    def __init__(
        self,
        *,
        additional_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        aof_storage_connection_string_0: builtins.str = ...,
        aof_storage_connection_string_1: builtins.str = ...,
        maxfragmentationmemory_reserved: builtins.str = ...,
        maxmemory_delta: builtins.str = ...,
        maxmemory_policy: builtins.str = ...,
        maxmemory_reserved: builtins.str = ...,
        rdb_backup_enabled: builtins.str = ...,
        rdb_backup_frequency: builtins.str = ...,
        rdb_backup_max_snapshot_count: builtins.str = ...,
        rdb_storage_connection_string: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_properties", b"additional_properties", "aof_storage_connection_string_0", b"aof_storage_connection_string_0", "aof_storage_connection_string_1", b"aof_storage_connection_string_1", "maxfragmentationmemory_reserved", b"maxfragmentationmemory_reserved", "maxmemory_delta", b"maxmemory_delta", "maxmemory_policy", b"maxmemory_policy", "maxmemory_reserved", b"maxmemory_reserved", "rdb_backup_enabled", b"rdb_backup_enabled", "rdb_backup_frequency", b"rdb_backup_frequency", "rdb_backup_max_snapshot_count", b"rdb_backup_max_snapshot_count", "rdb_storage_connection_string", b"rdb_storage_connection_string"]) -> None: ...

global___RedisCommonPropertiesRedisConfiguration = RedisCommonPropertiesRedisConfiguration

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_workspaces.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_workspaces.proto\x12\x1aoak9.tython.aws.workspaces\x1a\x13shared/shared.proto\"\xf7\x01\n\x1cWorkspaceWorkspaceProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63ompute_type_name\x18\x02 \x01(\t\x12\x1c\n\x14root_volume_size_gib\x18\x03 \x01(\x05\x12\x14\n\x0crunning_mode\x18\x04 \x01(\t\x12\x31\n)running_mode_auto_stop_timeout_in_minutes\x18\x05 \x01(\x05\x12\x1c\n\x14user_volume_size_gib\x18\x06 \x01(\x05\"\xb3\x03\n\tWorkspace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbundle_id\x18\x02 \x01(\t\x12\x14\n\x0c\x64irectory_id\x18\x03 \x01(\t\x12&\n\x1eroot_volume_encryption_enabled\x18\x04 \x01(\x08\x12=\n\x04tags\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.workspaces.Workspace.TagsEntry\x12\x11\n\tuser_name\x18\x06 \x01(\t\x12&\n\x1euser_volume_encryption_enabled\x18\x07 \x01(\x08\x12\x1d\n\x15volume_encryption_key\x18\x08 \x01(\t\x12V\n\x14workspace_properties\x18\t \x01(\x0b\x32\x38.oak9.tython.aws.workspaces.WorkspaceWorkspaceProperties\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\nWorkSpaces\x12\x38\n\tworkspace\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.workspaces.Workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_workspaces_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKSPACE_TAGSENTRY._options = None
  _WORKSPACE_TAGSENTRY._serialized_options = b'8\001'
  _WORKSPACEWORKSPACEPROPERTIES._serialized_start=78
  _WORKSPACEWORKSPACEPROPERTIES._serialized_end=325
  _WORKSPACE._serialized_start=328
  _WORKSPACE._serialized_end=763
  _WORKSPACE_TAGSENTRY._serialized_start=720
  _WORKSPACE_TAGSENTRY._serialized_end=763
  _WORKSPACES._serialized_start=765
  _WORKSPACES._serialized_end=835
# @@protoc_insertion_point(module_scope)
